mesos_cook
----------

A Python client and command-line tool for Two Sigma's Cook Mesos scheduler.

Configuration in ~/.cook::

    [cook]
    base_uri = http://my.cook.server:12321
    username = me
    password = secret

